# SPDX-FileCopyrightText: 2020 UMG MeDIC <marcel.parciak@med.uni-goettingen.de>
#
# SPDX-License-Identifier: GPL-3.0-or-later

import os
from typing import Any, Dict, List
from pydantic import BaseSettings
from tos_execute import __version__


class BasicSettings(BaseSettings):
    application_name: str = "Talend Open Studio Executor Agent"
    application_version: str = __version__.__version__
    talend_base_folder: str = "/etc/talend"
    talend_job_cache: str = "/tmp/jobs"
    talend_output_context_param: str = ""
    talend_parallel_jobs: int = 4
    talend_job_polling_time: int = 30
    db_uri: str = "postgresql://tos:agent@postgres:5432/tosagent"
    application_api_keys: List[str] = []


def get_version():
    return BasicSettings().application_version


agent_config_parameters = {
    "talend_job_cache",
    "talend_output_context_param",
}

agent_description = ""
with open(
    os.path.join(os.path.dirname(__file__), os.pardir, "README.md"), "r"
) as readme:
    agent_description = readme.read()
